@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
- * Copyright (c) 2008-2009 Harald Hvaal <haraldhv )@@@( stud(dot)ntnu.no>
+ * Copyright (c) 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
  * Copyright (c) 2009 Raphael Kubo da Costa <kubito@gmail.com>
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,8 +35,6 @@
 #include <KDebug>
 #include <KLocale>
 
-//#define KERFUFFLE_NOJOBTHREADING
-
 namespace Kerfuffle
 {
 Job::Job(ReadOnlyArchiveInterface *interface, QObject *parent)
@@ -55,26 +53,20 @@ Job::Job(ReadOnlyArchiveInterface *interface, QObject *parent)
 
 Job::~Job()
 {
-#ifndef KERFUFFLE_NOJOBTHREADING
     m_workerThread->wait();
     delete m_workerThread;
     m_workerThread = 0;
-#endif
 }
 
 void Job::start()
 {
-#ifdef KERFUFFLE_NOJOBTHREADING
-    QTimer::singleShot(0, this, SLOT(doWork()));
-#else
     m_workerThread = new ThreadExecution(this);
     m_workerThread->start();
-#endif
 }
 
 void Job::onError(const QString & message, const QString & details)
 {
-    Q_UNUSED(details);
+    Q_UNUSED(details)
 
     setError(1);
     setErrorText(message);
@@ -102,14 +94,10 @@ void Job::onEntryRemoved(const QString & path)
 
 void Job::onFinished(bool result)
 {
-    kDebug(1601);
+    kDebug() << result;
+
     m_interface->removeObserver(this);
 
-    setError(!result);
-
-    if (errorString().isEmpty())
-        setErrorText(i18n("An error occurred while performing the operation."));
-
     emitResult();
 }
 
@@ -120,10 +108,11 @@ void Job::onUserQuery(Query *query)
 
 bool Job::doKill()
 {
-    kDebug(1601);
+    kDebug();
     bool ret = m_interface->doKill();
-    if (!ret)
-        kDebug(1601) << "Killing does not seem to be supported here.";
+    if (!ret) {
+        kDebug() << "Killing does not seem to be supported here.";
+    }
     return ret;
 }
 
@@ -143,7 +132,24 @@ void ListJob::doWork()
     m_interface->registerObserver(this);
     bool ret = m_interface->list();
 
-    if (!m_interface->waitForFinishedSignal()) m_interface->finished(ret);
+    if (!m_interface->waitForFinishedSignal()) {
+        m_interface->finished(ret);
+    }
+}
+
+qlonglong ListJob::extractedFilesSize()
+{
+    return m_extractedFilesSize;
+}
+
+bool ListJob::isPasswordProtected()
+{
+    return m_isPasswordProtected;
+}
+
+bool ListJob::isSingleFolderArchive()
+{
+    return m_isSingleFolderArchive;
 }
 
 void ListJob::onNewEntry(const ArchiveEntry& entry)
@@ -170,6 +176,11 @@ void ListJob::onNewEntry(const ArchiveEntry& entry)
     }
 }
 
+QString ListJob::subfolderName() 
+{
+    return m_subfolderName;
+}
+
 ExtractJob::ExtractJob(const QList<QVariant>& files, const QString& destinationDir,
                        ExtractionOptions options, ReadOnlyArchiveInterface *interface, QObject *parent)
         : Job(interface,  parent), m_files(files), m_destinationDir(destinationDir), m_options(options)
@@ -190,15 +201,16 @@ void ExtractJob::doWork()
 
     fillInDefaultValues(m_options);
 
-    kDebug(1601) << "Starting extraction with selected files "
-    << m_files
-    << " Destination dir " << m_destinationDir
-    << " And options " << m_options
-    ;
+    kDebug() << "Starting extraction with selected files:"
+             << m_files
+             << "Destination dir:" << m_destinationDir
+             << "Options:" << m_options;
 
     bool ret = m_interface->copyFiles(m_files, m_destinationDir, m_options);
 
-    if (!m_interface->waitForFinishedSignal()) m_interface->finished(ret);
+    if (!m_interface->waitForFinishedSignal()) {
+        m_interface->finished(ret);
+    }
 }
 
 void ExtractJob::fillInDefaultValues(ExtractionOptions& options)
@@ -211,7 +223,7 @@ void ExtractJob::fillInDefaultValues(ExtractionOptions& options)
 AddJob::AddJob(const QStringList& files, const CompressionOptions& options , ReadWriteArchiveInterface *interface, QObject *parent)
         : Job(interface, parent), m_files(files), m_options(options)
 {
-    kDebug(1601);
+    kDebug();
 }
 
 void AddJob::doWork()
@@ -227,7 +239,9 @@ void AddJob::doWork()
     m_writeInterface->registerObserver(this);
     bool ret = m_writeInterface->addFiles(m_files, m_options);
 
-    if (!m_interface->waitForFinishedSignal()) m_interface->finished(ret);
+    if (!m_interface->waitForFinishedSignal()) {
+        m_interface->finished(ret);
+    }
 }
 
 DeleteJob::DeleteJob(const QList<QVariant>& files, ReadWriteArchiveInterface *interface, QObject *parent)
@@ -248,7 +262,9 @@ void DeleteJob::doWork()
     m_writeInterface->registerObserver(this);
     int ret = m_writeInterface->deleteFiles(m_files);
 
-    if (!m_interface->waitForFinishedSignal()) m_interface->finished(ret);
+    if (!m_interface->waitForFinishedSignal()) {
+        m_interface->finished(ret);
+    }
 }
 } // namespace Kerfuffle
 
