@@ -25,7 +25,6 @@
 
 #include "iraction.h"
 #include "profileserver.h"
-#include "remoteserver.h"
 
 #include <QVariant>
 
@@ -33,53 +32,49 @@
 #include <kconfiggroup.h>
 #include <klocale.h>
 
-KDE_EXPORT IRAction::IRAction(const QString &newProgram, const QString &newObject, const QString &newMethod, const Arguments &newArguments, const QString &newRemote, const QString &newMode, const QString &newButton, const bool newRepeat, const bool newAutoStart, const bool newDoBefore, const bool newDoAfter, const bool newUnique, const IfMulti newIfMulti)
-{
-    theProgram = newProgram;
-    theObject = newObject;
-    theMethod = newMethod;
-    theArguments = newArguments;
-    theRemote = newRemote;
-    theMode = newMode;
-    theButton = newButton;
-    theRepeat = newRepeat;
-    theDoAfter = newDoAfter;
-    theDoBefore = newDoBefore;
-    theAutoStart = newAutoStart;
-    theUnique = newUnique;
-    theIfMulti = newIfMulti;
-}
-
 KDE_EXPORT IRAction *IRAction::loadFromConfig(KConfig &theConfig, int index)
 {
-    IRAction *action = new IRAction();
-    KConfigGroup actionGroup = theConfig.group("Actions");
+  
+    //Read Config
     QString Binding = "Binding" + QString().setNum(index);
+    KConfigGroup actionGroup = theConfig.group("Actions");    
     QString helperString = actionGroup.readEntry(Binding + "Arguments", QString());
     int numArguments = helperString.toInt();
-    action->theArguments.clear();
+    Arguments tArguments = Arguments();
+    
     for (int j = 0; j < numArguments; j++) {
         QVariant::Type theType = QVariant::nameToType(actionGroup.readEntry(Binding + "ArgumentType" + QString().setNum(j), QString().toLocal8Bit()));
 	QVariant newArg = actionGroup.readEntry(Binding + "Argument" + QString().setNum(j), QVariant(theType));
-        action->theArguments.append(newArg);
+        tArguments.append(newArg);
     }
 
-    kDebug() << "Arguments: " << action->theArguments.getArgumentsList();
-
-    action->theProgram = actionGroup.readEntry(Binding + "Program", QString());
-    action->theObject = actionGroup.readEntry(Binding + "Object", QString());
-    action->theMethod.setPrototype(actionGroup.readEntry(Binding + "Method", QString()));
-    action->theRemote = actionGroup.readEntry(Binding + "Remote", QString());
-    action->theMode = actionGroup.readEntry(Binding + "Mode", QString());
-    action->theButton = actionGroup.readEntry(Binding + "Button", QString());
-    action->theRepeat = actionGroup.readEntry(Binding + "Repeat", QVariant(QVariant::Bool)).toBool();
-    action->theDoBefore = actionGroup.readEntry(Binding + "DoBefore", QVariant(QVariant::Bool)).toBool();
-    action->theDoAfter = actionGroup.readEntry(Binding + "DoAfter", QVariant(QVariant::Bool)).toBool();
-    action->theAutoStart = actionGroup.readEntry(Binding + "AutoStart", QVariant(QVariant::Bool)).toBool();
-    action->theUnique = actionGroup.readEntry(Binding + "Unique", QVariant(QVariant::Bool)).toBool();
-    helperString = actionGroup.readEntry(Binding + "IfMulti", QString());
-    action->theIfMulti = (IfMulti)helperString.toInt();
-
+    QString tProgram = actionGroup.readEntry(Binding + "Program", QString());
+    QString tObject = actionGroup.readEntry(Binding + "Object", QString());
+    QString tPrototype = actionGroup.readEntry(Binding + "Method", QString());
+    QString tRemote  = actionGroup.readEntry(Binding + "Remote", QString());
+    QString tMode  = actionGroup.readEntry(Binding + "Mode", QString());
+    QString tButton =  actionGroup.readEntry(Binding + "Button", QString());
+    bool tRepeat = actionGroup.readEntry(Binding + "Repeat", QVariant(QVariant::Bool)).toBool();
+    bool tDoBefore = actionGroup.readEntry(Binding + "DoBefore", QVariant(QVariant::Bool)).toBool();
+    bool tDoAfter = actionGroup.readEntry(Binding + "DoAfter", QVariant(QVariant::Bool)).toBool();
+    bool tAutoStart = actionGroup.readEntry(Binding + "AutoStart", QVariant(QVariant::Bool)).toBool();
+    bool tUnique = actionGroup.readEntry(Binding + "Unique", QVariant(QVariant::Bool)).toBool();
+    
+    IfMulti ifMulti = (IfMulti) actionGroup.readEntry(Binding + "IfMulti", QVariant(QVariant::Int).toInt());
+    
+    //Fill irAction
+    IRAction *action = new IRAction(tRemote,tButton);    
+    action->theProgram = tProgram;
+    action->theObject  = tObject;
+    action->theMethod.setPrototype(tPrototype);
+    action->theMode = tMode;
+    action->theRepeat = tRepeat;    
+    action->theDoBefore = tDoBefore;
+    action->theDoAfter=tDoAfter;
+    action->theAutoStart = tAutoStart;
+    action->theUnique = tUnique;
+    action->theIfMulti = ifMulti;    
+    action->theArguments = tArguments;
     return action;
 }
 
@@ -93,9 +88,6 @@ KDE_EXPORT void IRAction::saveToConfig(KConfig &theConfig, int index) const
     for (int j = 0; j < theArguments.count(); j++) {
         QVariant arg = theArguments.at(j);
         QVariant::Type preType = arg.type();
-        /*  if(preType == QVariant::StringList && arg.toString().isNull()){
-           arg = "";
-          }*/
         actionGroup.writeEntry(Binding + "Argument" + QString().setNum(j), arg);
         actionGroup.writeEntry(Binding + "ArgumentType" + QString().setNum(j), QVariant::typeToName(preType));
         kDebug() << "writeEntryType is" << QVariant::typeToName(preType) << "argument" << arg;
@@ -103,9 +95,9 @@ KDE_EXPORT void IRAction::saveToConfig(KConfig &theConfig, int index) const
     actionGroup.writeEntry(Binding + "Program", theProgram);
     actionGroup.writeEntry(Binding + "Object", theObject);
     actionGroup.writeEntry(Binding + "Method", theMethod.prototype());
-    actionGroup.writeEntry(Binding + "Remote", theRemote);
+    actionGroup.writeEntry(Binding + "Remote", theRemoteButton.remoteName());
     actionGroup.writeEntry(Binding + "Mode", theMode);
-    actionGroup.writeEntry(Binding + "Button", theButton);
+    actionGroup.writeEntry(Binding + "Button", theRemoteButton.name());
     actionGroup.writeEntry(Binding + "Repeat", theRepeat);
     actionGroup.writeEntry(Binding + "DoBefore", theDoBefore);
     actionGroup.writeEntry(Binding + "DoAfter", theDoAfter);
@@ -116,7 +108,7 @@ KDE_EXPORT void IRAction::saveToConfig(KConfig &theConfig, int index) const
 
 KDE_EXPORT const QString IRAction::function() const
 {
-    ProfileServer *theServer = ProfileServer::profileServer();
+    ProfileServer *theServer = ProfileServer::getInstance();
     if (theProgram.isEmpty())
         if (theObject.isEmpty())
             return i18n("Exit mode");
@@ -134,28 +126,12 @@ KDE_EXPORT const QString IRAction::function() const
         }
 }
 
-KDE_EXPORT const QString IRAction::notes() const
-{
-
-    if (isModeChange())
-        return QString(theDoBefore ? i18n("Do actions before. ") : "") +
-               QString(theDoAfter ? i18n("Do actions after. ") : "");
-    else if (isJustStart())
-        return "";
-    else
-        return QString(theAutoStart ? i18n("Auto-start. ") : "")
-               + QString(theRepeat ? i18n("Repeatable. ") : "")
-               + QString(!theUnique ? (theIfMulti == IM_DONTSEND ? i18n("Do nothing if many instances. ")
-                                       : theIfMulti == IM_SENDTOTOP ? i18n("Send to top instance. ")
-                                       : theIfMulti == IM_SENDTOBOTTOM ? i18n("Send to bottom instance. ") : i18n("Send to all instances. "))
-                                 : "");
-}
 
 KDE_EXPORT const QString IRAction::application() const
 {
-    ProfileServer *theServer = ProfileServer::profileServer();
+    ProfileServer *theServer = ProfileServer::getInstance();
     if (theProgram.isEmpty())
-        return "";
+        return QString();
     else {
 	const Profile *a = theServer->getProfileById(theProgram);
         if (a)
@@ -164,14 +140,3 @@ KDE_EXPORT const QString IRAction::application() const
             return theProgram;
     }
 }
-
-const QString IRAction::remoteName() const
-{
-    return RemoteServer::remoteServer()->getRemoteName(theRemote);
-}
-
-KDE_EXPORT const QString IRAction::buttonName() const
-{
-    return RemoteServer::remoteServer()->getButtonName(theRemote, theButton);
-}
-
