@@ -128,7 +128,7 @@ void KeyServer::slotDownloadKeysFinished(int resultcode)
 	if (resultcode == KGpgTransaction::TS_USER_ABORTED)
 		return;
 
-	const QStringList keys(KGpgImport::getImportedIds(log));
+	const QStringList keys(KGpgImport::getDetailedImportMessage(log));
 	const QString resultmessage(KGpgImport::getImportMessage(log));
 
 	if (!keys.empty())
@@ -198,6 +198,7 @@ void KeyServer::slotSearch()
 	m_dialogserver->enableButtonOk(false);
 	m_listpop = new searchRes(m_dialogserver);
 	m_listpop->kLVsearch->setModel(&m_filtermodel);
+	m_listpop->kLVsearch->setColumnWidth(0, 180);
 	m_listpop->statusText->setText(i18n("Connecting to the server..."));
 
 	connect(m_listpop->filterEdit, SIGNAL(textChanged(const QString &)), SLOT(slotSetFilterString(const QString &)));
@@ -263,15 +264,15 @@ void KeyServer::slotSearchRead(GPGProc *p)
 	QString line;
 
 	while (p->readln(line, true) >= 0) {
-		if (line.startsWith("[GNUPG:] GET_LINE keysearch.prompt")) {
+		if (line.startsWith(QLatin1String("[GNUPG:] GET_LINE keysearch.prompt"))) {
 			if (m_count < 4)
 				p->write("N\n");
 			else
 				p->write("Q\n");
-		} else if (line.startsWith("[GNUPG:] GOT_IT")) {
+		} else if (line.startsWith(QLatin1String("[GNUPG:] GOT_IT"))) {
 			m_count++;
 			line.clear();
-		} else if (!line.isEmpty() && !line.startsWith("[GNUPG:] ")) {
+		} else if (!line.isEmpty() && !line.startsWith(QLatin1String("[GNUPG:] "))) {
 			m_resultmodel->addResultLine(line);
 		}
 	}
@@ -328,7 +329,7 @@ void KeyServer::transferKeyID()
 {
 	QSet<QString> ids;
 
-	foreach (QModelIndex index, m_listpop->kLVsearch->selectionModel()->selectedIndexes())
+	foreach (const QModelIndex &index, m_listpop->kLVsearch->selectionModel()->selectedIndexes())
 		ids << m_resultmodel->idForIndex(m_filtermodel.mapToSource(index));
 
 	const QStringList idlist(ids.toList());
