@@ -19,6 +19,7 @@
 #define KGPGAPPLET_H
 
 #include <KUniqueApplication>
+#include <KShortcut>
 #include <KUrl>
 
 class KCmdLineArgs;
@@ -37,6 +38,7 @@ public:
     int newInstance ();
     bool running;
     KUrl::List urlList;
+    KShortcut goHome;
 
 protected:
     KCmdLineArgs *args;
